@@ -12,6 +12,7 @@
 #include "hgs_funs.h"
 
 using Eigen::log;
+using Eigen::abs;
 using Eigen::ArrayXd;
 using Eigen::ArrayXXd;
 using Eigen::MatrixXd;
@@ -48,7 +49,7 @@ SEXP Ap_int_nmE(const Eigen::MatrixXd A, const Eigen::ArrayXd mu,
 
 
 //' @describeIn qfrm_cpp
-//'   \code{qfpm_ABpq_int()}, central & vector
+//'   \code{qfpm_ABpq_int()}, central and vector
 //'
 // [[Rcpp::export]]
 SEXP ABpq_int_cvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
@@ -60,7 +61,7 @@ SEXP ABpq_int_cvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
 }
 
 //' @describeIn qfrm_cpp
-//'   \code{qfpm_ABpq_int()}, central & matrix
+//'   \code{qfpm_ABpq_int()}, central and matrix
 //'
 // [[Rcpp::export]]
 SEXP ABpq_int_cmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LB,
@@ -73,7 +74,7 @@ SEXP ABpq_int_cmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LB,
 }
 
 //' @describeIn qfrm_cpp
-//'   \code{qfpm_ABpq_int()}, noncentral & vector
+//'   \code{qfpm_ABpq_int()}, noncentral and vector
 //'
 // [[Rcpp::export]]
 SEXP ABpq_int_nvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
@@ -85,7 +86,7 @@ SEXP ABpq_int_nvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
 }
 
 //' @describeIn qfrm_cpp
-//'   \code{qfpm_ABpq_int()}, noncentral & matrix
+//'   \code{qfpm_ABpq_int()}, noncentral and matrix
 //'
 // [[Rcpp::export]]
 SEXP ABpq_int_nmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LB,
@@ -99,7 +100,7 @@ SEXP ABpq_int_nmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LB,
 
 
 //' @describeIn qfrm_cpp
-//'   \code{qfpm_ABDpqr_int()}, central & vector
+//'   \code{qfpm_ABDpqr_int()}, central and vector
 //'
 // [[Rcpp::export]]
 SEXP ABDpqr_int_cvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
@@ -113,7 +114,7 @@ SEXP ABDpqr_int_cvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
 }
 
 //' @describeIn qfrm_cpp
-//'   \code{qfpm_ABDpqr_int()}, central & matrix
+//'   \code{qfpm_ABDpqr_int()}, central and matrix
 //'
 // [[Rcpp::export]]
 SEXP ABDpqr_int_cmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LB,
@@ -128,7 +129,7 @@ SEXP ABDpqr_int_cmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LB,
 }
 
 //' @describeIn qfrm_cpp
-//'   \code{qfpm_ABDpqr_int()}, noncentral & vector
+//'   \code{qfpm_ABDpqr_int()}, noncentral and vector
 //'
 // [[Rcpp::export]]
 SEXP ABDpqr_int_nvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
@@ -140,7 +141,7 @@ SEXP ABDpqr_int_nvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
 }
 
 //' @describeIn qfrm_cpp
-//'   \code{qfpm_ABDpqr_int()}, central & matrix
+//'   \code{qfpm_ABDpqr_int()}, central and matrix
 //'
 // [[Rcpp::export]]
 SEXP ABDpqr_int_nmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LB,
@@ -269,7 +270,7 @@ SEXP ApIq_npi_nvE(const Eigen::ArrayXd LA, const Eigen::MatrixXd UA, const doubl
 
 
 //' @describeIn qfrm_cpp
-//'   \code{qfrm_ApBq_int()}, central & vector
+//'   \code{qfrm_ApBq_int()}, central and vector
 //'
 // [[Rcpp::export]]
 SEXP ApBq_int_cvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
@@ -320,7 +321,7 @@ SEXP ApBq_int_cvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
 }
 
 //' @describeIn qfrm_cpp
-//'   \code{qfrm_ApBq_int()}, central & matrix
+//'   \code{qfrm_ApBq_int()}, central and matrix
 //'
 // [[Rcpp::export]]
 SEXP ApBq_int_cmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LA,
@@ -376,7 +377,7 @@ SEXP ApBq_int_cmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LA,
 }
 
 //' @describeIn qfrm_cpp
-//'   \code{qfrm_ApBq_int()}, noncentral & vector
+//'   \code{qfrm_ApBq_int()}, noncentral and vector
 //'
 // [[Rcpp::export]]
 SEXP ApBq_int_nvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
@@ -389,7 +390,6 @@ SEXP ApBq_int_nvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
     ArrayXd LBh = ArrayXd::Ones(n) - bB * LB;
     ArrayXd lscf = ArrayXd::Zero(m + 1);
     ArrayXd dks = htil2_pj_vE(LA, LBh, mu, m, p, lscf, thr_margin).row(p);
-    ArrayXd lscfp = lscf.row(p);
     ArrayXd ansseq = hgs_1dE(dks, q, n_ / 2 + p, ((p - q) * M_LN2 + q * log(bB)
                              + lgamma(p + 1) + lgamma(n_ / 2 + p - q) - lgamma(n_ / 2 + p)), lscf);
 
@@ -425,7 +425,7 @@ SEXP ApBq_int_nvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
 }
 
 //' @describeIn qfrm_cpp
-//'   \code{qfrm_ApBq_int()}, noncentral & matrix
+//'   \code{qfrm_ApBq_int()}, noncentral and matrix
 //'
 // [[Rcpp::export]]
 SEXP ApBq_int_nmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LA,
@@ -439,7 +439,6 @@ SEXP ApBq_int_nmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LA,
     DiagMatXd Bh = (ArrayXd::Ones(n) - bB * LB).matrix().asDiagonal();
     ArrayXd lscf = ArrayXd::Zero(m + 1);
     ArrayXd dks = htil2_pj_mE(A, Bh, mu, m, p, lscf, thr_margin).row(p);
-    ArrayXd lscfp = lscf.row(p);
     ArrayXd ansseq = hgs_1dE(dks, q, n_ / 2 + p, ((p - q) * M_LN2 + q * log(bB)
                              + lgamma(p + 1) + lgamma(n_ / 2 + p - q) - lgamma(n_ / 2 + p)), lscf);
 
@@ -479,7 +478,7 @@ SEXP ApBq_int_nmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LA,
 
 
 //' @describeIn qfrm_cpp
-//'   \code{qfrm_ApBq_npi()}, central & vector
+//'   \code{qfrm_ApBq_npi()}, central and vector
 //'
 // [[Rcpp::export]]
 SEXP ApBq_npi_cvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
@@ -502,7 +501,7 @@ SEXP ApBq_npi_cvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
 }
 
 //' @describeIn qfrm_cpp
-//'   \code{qfrm_ApBq_npi()}, central & matrix
+//'   \code{qfrm_ApBq_npi()}, central and matrix
 //'
 // [[Rcpp::export]]
 SEXP ApBq_npi_cmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LB,
@@ -525,7 +524,7 @@ SEXP ApBq_npi_cmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LB,
 }
 
 //' @describeIn qfrm_cpp
-//'   \code{qfrm_ApBq_npi()}, noncentral & vector
+//'   \code{qfrm_ApBq_npi()}, noncentral and vector
 //'
 // [[Rcpp::export]]
 SEXP ApBq_npi_nvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
@@ -548,7 +547,7 @@ SEXP ApBq_npi_nvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
 }
 
 //' @describeIn qfrm_cpp
-//'   \code{qfrm_ApBq_npi()}, noncentral & matrix
+//'   \code{qfrm_ApBq_npi()}, noncentral and matrix
 //'
 // [[Rcpp::export]]
 SEXP ApBq_npi_nmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LB,
@@ -573,7 +572,7 @@ SEXP ApBq_npi_nmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LB,
 
 
 //' @describeIn qfrm_cpp
-//'   \code{qfmrm_ApBIqr_int()}, central & vector
+//'   \code{qfmrm_ApBIqr_int()}, central and vector
 //'
 // [[Rcpp::export]]
 SEXP ApBIqr_int_cvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
@@ -626,7 +625,7 @@ SEXP ApBIqr_int_cvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
 }
 
 //' @describeIn qfrm_cpp
-//'   \code{qfmrm_ApBIqr_int()}, central & matrix
+//'   \code{qfmrm_ApBIqr_int()}, central and matrix
 //'
 // [[Rcpp::export]]
 SEXP ApBIqr_int_cmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LA,
@@ -684,7 +683,7 @@ SEXP ApBIqr_int_cmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LA,
 }
 
 //' @describeIn qfrm_cpp
-//'   \code{qfmrm_ApBIqr_int()}, noncentral & vector
+//'   \code{qfmrm_ApBIqr_int()}, noncentral and vector
 //'
 // [[Rcpp::export]]
 SEXP ApBIqr_int_nvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
@@ -741,7 +740,7 @@ SEXP ApBIqr_int_nvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
 }
 
 //' @describeIn qfrm_cpp
-//'   \code{qfmrm_ApBIqr_int()}, noncentral & matrix
+//'   \code{qfmrm_ApBIqr_int()}, noncentral and matrix
 //'
 // [[Rcpp::export]]
 SEXP ApBIqr_int_nmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LA,
@@ -803,7 +802,7 @@ SEXP ApBIqr_int_nmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LA,
 
 
 //' @describeIn qfrm_cpp
-//'   \code{qfmrm_ApBIqr_npi()}, central & vector
+//'   \code{qfmrm_ApBIqr_npi()}, central and vector
 //'
 // [[Rcpp::export]]
 SEXP ApBIqr_npi_cvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
@@ -828,7 +827,7 @@ SEXP ApBIqr_npi_cvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
 }
 
 //' @describeIn qfrm_cpp
-//'   \code{qfmrm_ApBIqr_npi()}, central & matrix
+//'   \code{qfmrm_ApBIqr_npi()}, central and matrix
 //'
 // [[Rcpp::export]]
 SEXP ApBIqr_npi_cmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LB,
@@ -853,7 +852,7 @@ SEXP ApBIqr_npi_cmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LB,
 }
 
 //' @describeIn qfrm_cpp
-//'   \code{qfmrm_ApBIqr_npi()}, noncentral & vector
+//'   \code{qfmrm_ApBIqr_npi()}, noncentral and vector
 //'
 // [[Rcpp::export]]
 SEXP ApBIqr_npi_nvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
@@ -878,7 +877,7 @@ SEXP ApBIqr_npi_nvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
 }
 
 //' @describeIn qfrm_cpp
-//'   \code{qfmrm_ApBIqr_npi()}, noncentral & matrix
+//'   \code{qfmrm_ApBIqr_npi()}, noncentral and matrix
 //'
 // [[Rcpp::export]]
 SEXP ApBIqr_npi_nmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LB,
@@ -904,7 +903,7 @@ SEXP ApBIqr_npi_nmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LB,
 
 
 //' @describeIn qfrm_cpp
-//'   \code{qfmrm_IpBDqr_gen()}, central & vector
+//'   \code{qfmrm_IpBDqr_gen()}, central and vector
 //'
 // [[Rcpp::export]]
 SEXP IpBDqr_gen_cvE(const Eigen::ArrayXd LB, const Eigen::ArrayXd LD,
@@ -928,7 +927,7 @@ SEXP IpBDqr_gen_cvE(const Eigen::ArrayXd LB, const Eigen::ArrayXd LD,
 }
 
 //' @describeIn qfrm_cpp
-//'   \code{qfmrm_IpBDqr_gen()}, central & matrix
+//'   \code{qfmrm_IpBDqr_gen()}, central and matrix
 //'
 // [[Rcpp::export]]
 SEXP IpBDqr_gen_cmE(const Eigen::ArrayXd LB, const Eigen::MatrixXd D,
@@ -953,7 +952,7 @@ SEXP IpBDqr_gen_cmE(const Eigen::ArrayXd LB, const Eigen::MatrixXd D,
 }
 
 //' @describeIn qfrm_cpp
-//'   \code{qfmrm_IpBDqr_gen()}, noncentral & vector
+//'   \code{qfmrm_IpBDqr_gen()}, noncentral and vector
 //'
 // [[Rcpp::export]]
 SEXP IpBDqr_gen_nvE(const Eigen::ArrayXd LB, const Eigen::ArrayXd LD,
@@ -978,7 +977,7 @@ SEXP IpBDqr_gen_nvE(const Eigen::ArrayXd LB, const Eigen::ArrayXd LD,
 }
 
 //' @describeIn qfrm_cpp
-//'   \code{qfmrm_IpBDqr_gen()}, noncentral & matrix
+//'   \code{qfmrm_IpBDqr_gen()}, noncentral and matrix
 //'
 // [[Rcpp::export]]
 SEXP IpBDqr_gen_nmE(const Eigen::ArrayXd LB, const Eigen::MatrixXd D,
@@ -1004,7 +1003,7 @@ SEXP IpBDqr_gen_nmE(const Eigen::ArrayXd LB, const Eigen::MatrixXd D,
 
 
 //' @describeIn qfrm_cpp
-//'   \code{qfmrm_ApBDqr_int()}, central & vector
+//'   \code{qfmrm_ApBDqr_int()}, central and vector
 //'
 // [[Rcpp::export]]
 SEXP ApBDqr_int_cvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
@@ -1031,7 +1030,7 @@ SEXP ApBDqr_int_cvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
 }
 
 //' @describeIn qfrm_cpp
-//'   \code{qfmrm_ApBDqr_int()}, central & matrix
+//'   \code{qfmrm_ApBDqr_int()}, central and matrix
 //'
 // [[Rcpp::export]]
 SEXP ApBDqr_int_cmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LB,
@@ -1059,7 +1058,7 @@ SEXP ApBDqr_int_cmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LB,
 }
 
 //' @describeIn qfrm_cpp
-//'   \code{qfmrm_ApBDqr_int()}, noncentral & vector
+//'   \code{qfmrm_ApBDqr_int()}, noncentral and vector
 //'
 // [[Rcpp::export]]
 SEXP ApBDqr_int_nvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
@@ -1088,7 +1087,7 @@ SEXP ApBDqr_int_nvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
 }
 
 //' @describeIn qfrm_cpp
-//'   \code{qfmrm_ApBDqr_int()}, noncentral & matrix
+//'   \code{qfmrm_ApBDqr_int()}, noncentral and matrix
 //'
 // [[Rcpp::export]]
 SEXP ApBDqr_int_nmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LB,
@@ -1118,7 +1117,7 @@ SEXP ApBDqr_int_nmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LB,
 
 
 //' @describeIn qfrm_cpp
-//'   \code{qfmrm_ApBDqr_npi()}, central & vector
+//'   \code{qfmrm_ApBDqr_npi()}, central and vector
 //'
 // [[Rcpp::export]]
 SEXP ApBDqr_npi_cvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
@@ -1144,7 +1143,7 @@ SEXP ApBDqr_npi_cvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
 }
 
 //' @describeIn qfrm_cpp
-//'   \code{qfmrm_ApBDqr_npi()}, central & matrix
+//'   \code{qfmrm_ApBDqr_npi()}, central and matrix
 //'
 // [[Rcpp::export]]
 SEXP ApBDqr_npi_cmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LB,
@@ -1171,7 +1170,7 @@ SEXP ApBDqr_npi_cmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LB,
 }
 
 //' @describeIn qfrm_cpp
-//'   \code{qfmrm_ApBDqr_npi()}, noncentral & vector
+//'   \code{qfmrm_ApBDqr_npi()}, noncentral and vector
 //'
 // [[Rcpp::export]]
 SEXP ApBDqr_npi_nvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
@@ -1199,7 +1198,7 @@ SEXP ApBDqr_npi_nvE(const Eigen::ArrayXd LA, const Eigen::ArrayXd LB,
 }
 
 //' @describeIn qfrm_cpp
-//'   \code{qfmrm_ApBDqr_npi()}, noncentral & matrix
+//'   \code{qfmrm_ApBDqr_npi()}, noncentral and matrix
 //'
 // [[Rcpp::export]]
 SEXP ApBDqr_npi_nmE(const Eigen::MatrixXd A, const Eigen::ArrayXd LB,
